You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sis.apache.org by de...@apache.org on 2023/02/07 10:52:43 UTC

[sis] 01/02: Spelling fix: emphase → emphasis.

This is an automated email from the ASF dual-hosted git repository.

desruisseaux pushed a commit to branch geoapi-4.0
in repository https://gitbox.apache.org/repos/asf/sis.git

commit ade88f1efd3df11d64ea04a0aca45279d0603ff5
Author: Martin Desruisseaux <ma...@geomatys.com>
AuthorDate: Mon Feb 6 12:28:40 2023 +0100

    Spelling fix: emphase → emphasis.
---
 .../org/apache/sis/internal/book/CodeColorizer.java    | 16 ++++++++--------
 .../main/java/org/apache/sis/image/PlanarImage.java    |  2 +-
 .../src/main/java/org/apache/sis/io/wkt/Colors.java    |  2 +-
 .../org/apache/sis/util/logging/MonolineFormatter.java | 18 +++++++++---------
 4 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/PlanarImage.java b/core/sis-feature/src/main/java/org/apache/sis/image/PlanarImage.java
index 33aa883b41..b13324d3c6 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/PlanarImage.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/PlanarImage.java
@@ -43,7 +43,7 @@ import static java.lang.Math.multiplyFull;
 
 /**
  * Base class of {@link RenderedImage} implementations in Apache SIS.
- * The "Planar" part in the class name emphases that this image is a representation
+ * The "Planar" part in the class name emphasizes that this image is a representation
  * of two-dimensional data and should not contain an image with three-dimensional effects.
  * Planar images can be used as data storage for {@link org.apache.sis.coverage.grid.GridCoverage2D}.
  *
diff --git a/core/sis-referencing/src/main/java/org/apache/sis/io/wkt/Colors.java b/core/sis-referencing/src/main/java/org/apache/sis/io/wkt/Colors.java
index 61e7644f7c..09f4dfb349 100644
--- a/core/sis-referencing/src/main/java/org/apache/sis/io/wkt/Colors.java
+++ b/core/sis-referencing/src/main/java/org/apache/sis/io/wkt/Colors.java
@@ -77,7 +77,7 @@ public class Colors implements Cloneable, Serializable {
     }
 
     /**
-     * Emphases on identification information
+     * Emphasis on identification information
      * ({@linkplain org.apache.sis.referencing.AbstractIdentifiedObject#getName() name} and
      *  {@linkplain org.apache.sis.referencing.AbstractIdentifiedObject#getIdentifiers() identifiers}) only.
      * This map is immutable.
diff --git a/core/sis-utility/src/main/java/org/apache/sis/util/logging/MonolineFormatter.java b/core/sis-utility/src/main/java/org/apache/sis/util/logging/MonolineFormatter.java
index f61f0ed51d..8dd2238882 100644
--- a/core/sis-utility/src/main/java/org/apache/sis/util/logging/MonolineFormatter.java
+++ b/core/sis-utility/src/main/java/org/apache/sis/util/logging/MonolineFormatter.java
@@ -656,16 +656,16 @@ loop:   for (int i=0; ; i++) {
     @Override
     public String format(final LogRecord record) {
         boolean faint = false;                      // Whether to use faint text for level < INFO.
-        String emphaseStart = "";                   // ANSI escape sequence for bold text if we use it.
-        String emphaseEnd   = "";                   // ANSI escape sequence for stopping bold text if we use it.
+        String emphasisStart = "";                  // ANSI escape sequence for bold text if we use it.
+        String emphasisEnd   = "";                  // ANSI escape sequence for stopping bold text if we use it.
         final Level level = record.getLevel();
         final StringBuffer buffer = this.buffer;
         synchronized (buffer) {
             final boolean colors = (this.colors != null);
             if (colors && level.intValue() >= LEVEL_THRESHOLD.intValue()) {
-                emphaseStart = X364.BOLD.sequence();
-                emphaseEnd   = X364.NORMAL.sequence();
-                faint        = faintSupported;
+                emphasisStart = X364.BOLD.sequence();
+                emphasisEnd   = X364.NORMAL.sequence();
+                faint         = faintSupported;
             }
             buffer.setLength(header.length());
             /*
@@ -689,10 +689,10 @@ loop:   for (int i=0; ; i++) {
                     levelColor = colorAt(level);
                     levelReset = X364.BACKGROUND_DEFAULT.sequence();
                 }
-                final int offset = buffer.append(levelColor).append(emphaseStart).length();
+                final int offset = buffer.append(levelColor).append(emphasisStart).length();
                 final int length = buffer.append(level.getLocalizedName()).length() - offset;
-                buffer.append(emphaseEnd).append(CharSequences.spaces(levelWidth - length));
-                margin += buffer.length() - emphaseEnd.length() - offset;
+                buffer.append(emphasisEnd).append(CharSequences.spaces(levelWidth - length));
+                margin += buffer.length() - emphasisEnd.length() - offset;
                 buffer.append(levelReset).append(' ');
             }
             /*
@@ -721,7 +721,7 @@ loop:   for (int i=0; ; i++) {
                 if (sourceFormat == METHOD) {
                     source = source + '.' + record.getSourceMethodName();
                 }
-                buffer.append(emphaseStart).append('[').append(source).append(']').append(emphaseEnd).append(' ');
+                buffer.append(emphasisStart).append('[').append(source).append(']').append(emphasisEnd).append(' ');
             }
             /*
              * Now prepare the LineAppender for the message. We set a line separator prefixed by some
diff --git a/core/sis-build-helper/src/main/java/org/apache/sis/internal/book/CodeColorizer.java b/core/sis-build-helper/src/main/java/org/apache/sis/internal/book/CodeColorizer.java
index 0ed3e380e1..7c50438599 100644
--- a/core/sis-build-helper/src/main/java/org/apache/sis/internal/book/CodeColorizer.java
+++ b/core/sis-build-helper/src/main/java/org/apache/sis/internal/book/CodeColorizer.java
@@ -381,26 +381,26 @@ public final class CodeColorizer {
                             }
                             /*
                              * The following code is executed for each word which is a valid Java identifier.
                              * Different kind of emphase may be applied: bold for Java keywords, some colors
                              * for OGC/ISO classes, other colors for SIS classes, etc.
                              */
                             final String word = text.substring(lower, upper);
-                            Element emphase = null;
+                            Element emphasis = null;
                             if (JAVA_KEYWORDS.contains(word)) {
-                                emphase = document.createElement("b");
+                                emphasis = document.createElement("b");
                             } else if (isJava) {
                                 final Specifier origin = getSpecifier(word);
                                 if (origin != null) {
-                                    emphase = document.createElement("code");
-                                    emphase.setAttribute("class", origin.style);
+                                    emphasis = document.createElement("code");
+                                    emphasis.setAttribute("class", origin.style);
                                 }
                             }
-                            if (emphase != null) {
-                                emphase.setTextContent(word);
+                            if (emphasis != null) {
+                                emphasis.setTextContent(word);
                                 if (nextSubstringStart != lower) {
                                     parent.insertBefore(document.createTextNode(text.substring(nextSubstringStart, lower)), node);
                                 }
-                                parent.insertBefore(emphase, node);
+                                parent.insertBefore(emphasis, node);
                                 nextSubstringStart = upper;
                             }
                             lower = upper;
@@ -381,26 +381,26 @@ public final class CodeColorizer {
                             /*
                              * The following code is executed for each word which is a valid Java identifier.
-                             * Different kind of emphase may be applied: bold for Java keywords, some colors
+                             * Different kind of emphasis may be applied: bold for Java keywords, some colors
                              * for OGC/ISO classes, other colors for SIS classes, etc.
                              */